![Python application](https://github.com/sunpip/Mandarina/workflows/Python%20application/badge.svg)

Mandarina
======
**Mandarina** is a friendly Data Science library for Python

## Functionality

At the moment, Mandarina provides the following modules:
- Csv file functions
- Random data generators 
- Code benchmarking tools
- Tools to work with files and directories
- Scheduling functions 
- Custom iterators 
- Image manipulation functions

## License 
* Check the [LICENSE](https://github.com/sunpip/Mandarina/blob/master/LICENSE) file

## Authors

- Alen Frey

## Version 
* Version 0.0.11

## How to install
```shell script
pip install mandarina
```
